==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/policy/auth/policy_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth!message" line="0"/>
			<source>Authentication is required to view the log</source>
			<translation>المصادقة مطلوبة لعرض السجل</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.self!message" line="0"/>
			<source>Authentication is required to view the log</source>
			<translation>المصادقة مطلوبة لعرض السجل</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.self!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogs!message" line="0"/>
			<source>Authentication is required to export logs</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogs!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogsSelf!message" line="0"/>
			<source>Authentication is required to export logs</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogsSelf!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
	</context>
</TS>

==> deepin-log-viewer_6.5.10+ds1.orig.tar.xz: deepin-log-viewer-6.5.10/translations/policy/auth/policy_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth!message" line="0"/>
			<source>Authentication is required to view the log</source>
			<translation>المصادقة مطلوبة لعرض السجل</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.self!message" line="0"/>
			<source>Authentication is required to view the log</source>
			<translation>المصادقة مطلوبة لعرض السجل</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.self!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogs!message" line="0"/>
			<source>Authentication is required to export logs</source>
			<translation>التوثيق مطلوب للتصدير السجلات</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogs!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogsSelf!message" line="0"/>
			<source>Authentication is required to export logs</source>
			<translation>التوثيق مطلوب للتصدير السجلات</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerAuth.exportLogsSelf!description" line="0"/>
			<source>authentication</source>
			<translation>المصادقة</translation>
		</message>
	</context>
</TS>
